@@ -29,7 +29,7 @@ class NativeThreadPool:
 
     __slots__ = ('max_thread', 'main_semaphore', 'sub_semaphore', 'exit_for_any_exception',
                  '_thread_res_queue', 'valid_for_new_thread', 'log_exception', 'thread_list',
-                 'completed_threads', 'killed_threads')
+                 'completed_threads', 'killed_threads', 'raise_exception', 'happened_exception')
 
     def __init__(self, **kwargs):
         assert 'total_thread_number' in kwargs or ('semaphore' in kwargs and 'max_thread' in kwargs)
@@ -42,9 +42,13 @@ class NativeThreadPool:
             self.main_semaphore = kwargs['semaphore']
             self.sub_semaphore = BoundedSemaphore(self.max_thread)
         self.exit_for_any_exception = kwargs.get("exit_for_any_exception", False)
-        self._thread_res_queue = Queue()
+        self.raise_exception = kwargs.get("raise_exception", False)
         self.valid_for_new_thread = True
+        self._thread_res_queue = Queue()
+        self.happened_exception = None
         self.log_exception = kwargs.get('log_exception', True)
+        if self.raise_exception:
+            self.log_exception = True
         self.thread_list = []
         self.completed_threads = set()
         self.killed_threads = set()
@@ -60,13 +64,13 @@ class NativeThreadPool:
         try:
             res = func(*args, **kwargs)
         except Exception as e:
+            self.happened_exception = e
             res = e
             err_msg = traceback.format_exc()
             if self.log_exception:
                 logging.error(f"Thread {thread_number} failed, error msg: \n{err_msg}")
             if self.exit_for_any_exception:
                 os._exit(-1)
-
             success = False
         finally:
             main_semaphore.release()
@@ -77,6 +81,8 @@ class NativeThreadPool:
 
     def apply_async(self, func, args=None, kwargs=None, daemon=True):
         assert self.valid_for_new_thread
+        if self.raise_exception and self.happened_exception is not None:
+            raise self.happened_exception
         self.main_semaphore.acquire()
         self.sub_semaphore.acquire()
         if args is None:
